@@ -2,4 +2,11 @@ from ._miniFasta import print_fasta, translate_seq, reverse_comp
 from ._reader import read
 from ._writer import write, fasta_object
 
-__all__ = ["fasta_object", "read", "write", "print_fasta", "translate_seq", "reverse_comp"]
+__all__ = [
+    "fasta_object",
+    "read",
+    "write",
+    "print_fasta",
+    "translate_seq",
+    "reverse_comp",
+]
